==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QUntypedPropertyData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qpropertyprivate.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QUntypedPropertyData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QUntypedPropertyData")
    QUntypedPropertyData *_ptr = reinterpret_cast<QUntypedPropertyData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QUntypedPropertyData_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QUntypedPropertyData *__qt_this = new(__qtjambi_ptr) QUntypedPropertyData();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QUntypedPropertyData
void __qt_destruct_QUntypedPropertyData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QUntypedPropertyData")
    reinterpret_cast<QUntypedPropertyData*>(ptr)->~QUntypedPropertyData();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QUntypedPropertyData::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QUntypedPropertyData_initialize_1native__Lio_qt_core_QUntypedPropertyData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QUntypedPropertyData::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QUntypedPropertyData_0, sizeof(QUntypedPropertyData), typeid(QUntypedPropertyData), false, &deleter_QUntypedPropertyData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QUntypedPropertyData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QUntypedPropertyData>("QUntypedPropertyData", "io/qt/core/QUntypedPropertyData");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QUntypedPropertyData, {
        ConstructorInfo(&__qt_construct_QUntypedPropertyData_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QUntypedPropertyData);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QUntypedPropertyData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qpropertyprivate.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QUntypedPropertyData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QUntypedPropertyData")
    QUntypedPropertyData *_ptr = reinterpret_cast<QUntypedPropertyData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QUntypedPropertyData()
void __qt_construct_QUntypedPropertyData(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QUntypedPropertyData()")
    Q_UNUSED(__java_arguments)
    QUntypedPropertyData *__qt_this = new(__qtjambi_ptr) QUntypedPropertyData();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QUntypedPropertyData::QUntypedPropertyData()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QUntypedPropertyData_initialize_1native__Lio_qt_core_QUntypedPropertyData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QUntypedPropertyData::QUntypedPropertyData()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QUntypedPropertyData, sizeof(QUntypedPropertyData), typeid(QUntypedPropertyData), false, &deleter_QUntypedPropertyData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QUntypedPropertyData
void __qt_destruct_QUntypedPropertyData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QUntypedPropertyData")
    reinterpret_cast<QUntypedPropertyData*>(ptr)->~QUntypedPropertyData();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QUntypedPropertyData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QUntypedPropertyData>("QUntypedPropertyData", "io/qt/core/QUntypedPropertyData");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QUntypedPropertyData, {
        ConstructorInfo(&__qt_construct_QUntypedPropertyData, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QUntypedPropertyData);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
